Release notes
=============

This is the list of changes to **naturf** between each release. For full details,
see the `commit logs <https://github.com/IMMM-SFA/naturf/commits>`_.

Version 0.1.0
_____________

- Initial release
